is_skeptically_accepted_at

Function is_skeptically_accepted_at 

pub fn is_skeptically_accepted_at<A>(
    framework: &WeightedFramework<A>,
    target: &A,
    budget: Budget,
) -> Result<bool, Error>
where A: Clone + Eq + Hash + Debug + Ord,
β-skeptical acceptance: target appears in every preferred extension of every β-inconsistent residual. Returns false for frameworks with no preferred extensions in any residual.